[devel] Imported from libpng-1.5.1beta03.tar
diff --git a/ANNOUNCE b/ANNOUNCE
index df7c003..6ccaa2b 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
 
-Libpng 1.5.1beta02 - January 14, 2011
+Libpng 1.5.1beta03 - January 15, 2011
 
 This is not intended to be a public release.  It will be replaced
 within a few weeks by a public version or by another test version.
@@ -9,20 +9,20 @@
 Source files with LF line endings (for Unix/Linux) and with a
 "configure" script
 
-   1.5.1beta02.tar.xz (LZMA-compressed, recommended)
-   1.5.1beta02.tar.gz
-   1.5.1beta02.tar.bz2
+   1.5.1beta03.tar.xz (LZMA-compressed, recommended)
+   1.5.1beta03.tar.gz
+   1.5.1beta03.tar.bz2
 
 Source files with CRLF line endings (for Windows), without the
 "configure" script
 
-   lp151b02.7z  (LZMA-compressed, recommended)
-   lp151b02.zip
+   lp151b03.7z  (LZMA-compressed, recommended)
+   lp151b03.zip
 
 Other information:
 
-   1.5.1beta02-README.txt
-   1.5.1beta02-LICENSE.txt
+   1.5.1beta03-README.txt
+   1.5.1beta03-LICENSE.txt
 
 Changes since the last public release (1.5.0):
 
@@ -39,6 +39,9 @@
   Fixed a bug in handling of interlaced images (bero at arklinux.org).
   Updated CMakeLists.txt (Clifford Yapp)
 
+Version 1.5.1beta03 [January 15, 2011]
+  Fixed typecasting of some png_debug() statements (Cosmin)
+
 Send comments/corrections/commendations to png-mng-implement at lists.sf.net:
 (subscription required; visit
 https://lists.sourceforge.net/lists/listinfo/png-mng-implement
diff --git a/CHANGES b/CHANGES
index 3f3c607..ea7cc91 100644
--- a/CHANGES
+++ b/CHANGES
@@ -3155,6 +3155,9 @@
   Fixed a bug in handling of interlaced images (bero at arklinux.org).
   Updated CMakeLists.txt (Clifford Yapp)
 
+Version 1.5.1beta03 [January 15, 2011]
+  Fixed typecasting of some png_debug() statements (Cosmin)
+
 Send comments/corrections/commendations to png-mng-implement at lists.sf.net
 (subscription required; visit
 https://lists.sourceforge.net/lists/listinfo/png-mng-implement
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 4a37783..6bc1058 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -264,7 +264,7 @@
 # SET UP LINKS
 if(PNG_SHARED)
   set_target_properties(${PNG_LIB_NAME} PROPERTIES
-#   VERSION 15.${PNGLIB_RELEASE}.1.5.1beta02
+#   VERSION 15.${PNGLIB_RELEASE}.1.5.1beta03
     VERSION 15.${PNGLIB_RELEASE}.0
     SOVERSION 15
     CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index a5bd00f..bb16857 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.1beta02, January 14, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.1beta03, January 15, 2011, are
 Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-January 14, 2011
+January 15, 2011
diff --git a/README b/README
index dc4bc3f..8e2b1c1 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.1beta02 - January 14, 2011 (shared library 15.0)
+README for libpng version 1.5.1beta03 - January 15, 2011 (shared library 15.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/configure b/configure
index 818fd28..6f83310 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.68 for libpng 1.5.1beta02
+# Generated by GNU Autoconf 2.68 for libpng 1.5.1beta03
 #
 # Report bugs to <png-mng-implement@lists.sourceforge.net>.
 #
@@ -570,8 +570,8 @@
 # Identity of this package.
 PACKAGE_NAME='libpng'
 PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.5.1beta02'
-PACKAGE_STRING='libpng 1.5.1beta02'
+PACKAGE_VERSION='1.5.1beta03'
+PACKAGE_STRING='libpng 1.5.1beta03'
 PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
 PACKAGE_URL=''
 
@@ -1306,7 +1306,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures libpng 1.5.1beta02 to adapt to many kinds of systems.
+\`configure' configures libpng 1.5.1beta03 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1376,7 +1376,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of libpng 1.5.1beta02:";;
+     short | recursive ) echo "Configuration of libpng 1.5.1beta03:";;
    esac
   cat <<\_ACEOF
 
@@ -1484,7 +1484,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-libpng configure 1.5.1beta02
+libpng configure 1.5.1beta03
 generated by GNU Autoconf 2.68
 
 Copyright (C) 2010 Free Software Foundation, Inc.
@@ -1907,7 +1907,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by libpng $as_me 1.5.1beta02, which was
+It was created by libpng $as_me 1.5.1beta03, which was
 generated by GNU Autoconf 2.68.  Invocation command line was
 
   $ $0 $@
@@ -2722,7 +2722,7 @@
 
 # Define the identity of the package.
  PACKAGE='libpng'
- VERSION='1.5.1beta02'
+ VERSION='1.5.1beta03'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -2786,7 +2786,7 @@
 
 
 
-PNGLIB_VERSION=1.5.1beta02
+PNGLIB_VERSION=1.5.1beta03
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=5
 PNGLIB_RELEASE=1
@@ -12993,7 +12993,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by libpng $as_me 1.5.1beta02, which was
+This file was extended by libpng $as_me 1.5.1beta03, which was
 generated by GNU Autoconf 2.68.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -13059,7 +13059,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-libpng config.status 1.5.1beta02
+libpng config.status 1.5.1beta03
 configured by $0, generated by GNU Autoconf 2.68,
   with options \\"\$ac_cs_config\\"
 
diff --git a/configure.ac b/configure.ac
index 57ebf36..740e5f1 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,12 +18,12 @@
 
 dnl Version number stuff here:
 
-AC_INIT([libpng], [1.5.1beta02], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.5.1beta03], [png-mng-implement@lists.sourceforge.net])
 AM_INIT_AUTOMAKE
 dnl stop configure from automagically running automake
 AM_MAINTAINER_MODE
 
-PNGLIB_VERSION=1.5.1beta02
+PNGLIB_VERSION=1.5.1beta03
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=5
 PNGLIB_RELEASE=1
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 75e8fe2..ee5dd2b 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.1beta02 - January 14, 2011
+ libpng version 1.5.1beta03 - January 15, 2011
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.1beta02 - January 14, 2011
+ libpng versions 0.97, January 1998, through 1.5.1beta03 - January 15, 2011
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
@@ -1075,7 +1075,7 @@
 As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
 added.  It expands the sample depth without changing tRNS to alpha.
 
-As of libpng version 1.5.1beta02, not all possible expansions are supported.
+As of libpng version 1.5.1beta03, not all possible expansions are supported.
 
 In the following table, the 01 means grayscale with depth<8, 31 means
 indexed with depth<8, other numerals represent the color type, "T" means
@@ -3838,13 +3838,13 @@
 
 XIV. Y2K Compliance in libpng
 
-January 14, 2011
+January 15, 2011
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.1beta02 are Y2K compliant.  It is my belief that earlier
+upward through 1.5.1beta03 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index 7fbec98..4b312a6 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "January 14, 2011"
+.TH LIBPNG 3 "January 15, 2011"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.1beta02
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.1beta03
 .SH SYNOPSIS
 \fI\fB
 
@@ -851,7 +851,7 @@
 .SH LIBPNG.TXT
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.1beta02 - January 14, 2011
+ libpng version 1.5.1beta03 - January 15, 2011
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -862,7 +862,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.1beta02 - January 14, 2011
+ libpng versions 0.97, January 1998, through 1.5.1beta03 - January 15, 2011
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
@@ -1926,7 +1926,7 @@
 As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
 added.  It expands the sample depth without changing tRNS to alpha.
 
-As of libpng version 1.5.1beta02, not all possible expansions are supported.
+As of libpng version 1.5.1beta03, not all possible expansions are supported.
 
 In the following table, the 01 means grayscale with depth<8, 31 means
 indexed with depth<8, other numerals represent the color type, "T" means
@@ -4689,13 +4689,13 @@
 
 .SH XIV. Y2K Compliance in libpng
 
-January 14, 2011
+January 15, 2011
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.1beta02 are Y2K compliant.  It is my belief that earlier
+upward through 1.5.1beta03 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
@@ -4878,7 +4878,8 @@
  1.5.0beta01-58      15    10500  15.so.15.0[.0]
  1.5.0rc01-07        15    10500  15.so.15.0[.0]
  1.5.0               15    10500  15.so.15.0[.0]
- 1.5.1beta01-02      15    10501  15.so.15.1[.0]
+ 1.5.1beta01-03      15    10501  15.so.15.1[.0]
+ 1.5.1rc01           15    10501  15.so.15.1[.0]
 
 Henceforth the source version will match the shared-library minor
 and patch numbers; the shared-library major version number will be
@@ -4935,7 +4936,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.5.1beta02 - January 14, 2011:
+Libpng version 1.5.1beta03 - January 15, 2011:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -4958,7 +4959,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.1beta02, January 14, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.1beta03, January 15, 2011, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -5057,7 +5058,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-January 14, 2011
+January 15, 2011
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index d0a33eb..e27b2aa 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "January 14, 2011"
+.TH LIBPNGPF 3 "January 15, 2011"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.1beta02
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.1beta03
 (private functions)
 .SH SYNOPSIS
 \fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index f15ffe9..2596761 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "January 14, 2011"
+.TH PNG 5 "January 15, 2011"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/png.c b/png.c
index 6d5a5fd..993921f 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
 #include "pngpriv.h"
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_1beta02 Your_png_h_is_not_version_1_5_1beta02;
+typedef png_libpng_version_1_5_1beta03 Your_png_h_is_not_version_1_5_1beta03;
 
 /* Tells libpng that we have already handled the first "num_bytes" bytes
  * of the PNG file signature.  If the PNG data is embedded into another
@@ -555,13 +555,13 @@
 #else
 #  ifdef __STDC__
    return PNG_STRING_NEWLINE \
-     "libpng version 1.5.1beta02 - January 14, 2011" PNG_STRING_NEWLINE \
+     "libpng version 1.5.1beta03 - January 15, 2011" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2011 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE;
 #  else
-      return "libpng version 1.5.1beta02 - January 14, 2011\
+      return "libpng version 1.5.1beta03 - January 15, 2011\
       Copyright (c) 1998-2011 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 7fea2dc..83bcc80 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.5.1beta02 - (PENDING RELEASE)
+ * libpng version 1.5.1beta03 - (PENDING RELEASE)
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngread.c b/pngread.c
index 056bcbd..2c8f2cd 100644
--- a/pngread.c
+++ b/pngread.c
@@ -1,7 +1,7 @@
 
 /* pngread.c - read a PNG file
  *
- * Last changed in libpng 1.5.0 [January 6, 2011]
+ * Last changed in libpng 1.5.1 [$RDATE%]
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrutil.c b/pngrutil.c
index 926e236..14e35ee 100644
--- a/pngrutil.c
+++ b/pngrutil.c
@@ -1,7 +1,7 @@
 
 /* pngrutil.c - utilities to read a PNG file
  *
- * Last changed in libpng 1.5.0 [January 6, 2011]
+ * Last changed in libpng 1.5.1 [(PENDING RELEASE)]
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -608,7 +608,7 @@
    png_ptr->rowbytes = PNG_ROWBYTES(png_ptr->pixel_depth, png_ptr->width);
    png_debug1(3, "bit_depth = %d", png_ptr->bit_depth);
    png_debug1(3, "channels = %d", png_ptr->channels);
-   png_debug1(3, "rowbytes = %u", png_ptr->rowbytes);
+   png_debug1(3, "rowbytes = %lu", (unsigned long)png_ptr->rowbytes);
    png_set_IHDR(png_ptr, info_ptr, width, height, bit_depth,
        color_type, interlace_type, compression_type, filter_type);
 }
@@ -3607,9 +3607,9 @@
    png_debug1(3, "height = %u,", png_ptr->height);
    png_debug1(3, "iwidth = %u,", png_ptr->iwidth);
    png_debug1(3, "num_rows = %u,", png_ptr->num_rows);
-   png_debug1(3, "rowbytes = %u,", png_ptr->rowbytes);
-   png_debug1(3, "irowbytes = %u",
-       PNG_ROWBYTES(png_ptr->pixel_depth, png_ptr->iwidth) + 1);
+   png_debug1(3, "rowbytes = %lu,", (unsigned long)png_ptr->rowbytes);
+   png_debug1(3, "irowbytes = %lu",
+       (unsigned long)PNG_ROWBYTES(png_ptr->pixel_depth, png_ptr->iwidth) + 1);
 
    png_ptr->flags |= PNG_FLAG_ROW_INIT;
 }
diff --git a/pngset.c b/pngset.c
index 113cd79..094e8b3 100644
--- a/pngset.c
+++ b/pngset.c
@@ -1,7 +1,7 @@
 
 /* pngset.c - storage of image information into info struct
  *
- * Last changed in libpng 1.5.0 [January 6, 2011]
+ * Last changed in libpng 1.5.1 [(PENDING RELEASE)]
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -352,7 +352,7 @@
 
    ++lengthw;
 
-   png_debug1(3, "allocating unit for info (%u bytes)", lengthw);
+   png_debug1(3, "allocating unit for info (%u bytes)", (unsigned int)lengthw);
 
    info_ptr->scal_s_width = (png_charp)png_malloc_warn(png_ptr, lengthw);
 
@@ -366,7 +366,7 @@
 
    ++lengthh;
 
-   png_debug1(3, "allocating unit for info (%u bytes)", lengthh);
+   png_debug1(3, "allocating unit for info (%u bytes)", (unsigned int)lengthh);
 
    info_ptr->scal_s_height = (png_charp)png_malloc_warn(png_ptr, lengthh);
 
@@ -751,10 +751,10 @@
       if (textp->key == NULL)
          return(1);
 
-      png_debug2(2, "Allocated %lu bytes at %x in png_set_text",
+      png_debug2(2, "Allocated %lu bytes at %p in png_set_text",
           (unsigned long)(png_uint_32)
           (key_len + lang_len + lang_key_len + text_length + 4),
-          (int)textp->key);
+          textp->key);
 
       png_memcpy(textp->key, text_ptr[i].key,(png_size_t)(key_len));
       *(textp->key + key_len) = '\0';
diff --git a/pngtest.c b/pngtest.c
index af51b13..f5117dd 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1784,4 +1784,4 @@
 }
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_1beta02 Your_png_h_is_not_version_1_5_1beta02;
+typedef png_libpng_version_1_5_1beta03 Your_png_h_is_not_version_1_5_1beta03;
diff --git a/pngwrite.c b/pngwrite.c
index c3922f0..a276d7c 100644
--- a/pngwrite.c
+++ b/pngwrite.c
@@ -1,7 +1,7 @@
 
 /* pngwrite.c - general routines to write a PNG file
  *
- * Last changed in libpng 1.5.0 [January 6, 2011]
+ * Last changed in libpng 1.5.1 [(PENDING RELEASE)]
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -783,7 +783,8 @@
    png_debug1(3, "row_info->channels = %d", png_ptr->row_info.channels);
    png_debug1(3, "row_info->bit_depth = %d", png_ptr->row_info.bit_depth);
    png_debug1(3, "row_info->pixel_depth = %d", png_ptr->row_info.pixel_depth);
-   png_debug1(3, "row_info->rowbytes = %u", png_ptr->row_info.rowbytes);
+   png_debug1(3, "row_info->rowbytes = %lu",
+       (unsigned long)png_ptr->row_info.rowbytes);
 
    /* Copy user's row into buffer, leaving room for filter byte. */
    png_memcpy(png_ptr->row_buf + 1, row, png_ptr->row_info.rowbytes);
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index ea479c9..8044b61 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.5.1beta02 - January 14, 2011
+libpng version 1.5.1beta03 - January 15, 2011
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 8b378e1..c35d8f5 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.5.1beta02 - January 14, 2011
+ * libpng version 1.5.1beta03 - January 15, 2011
  *
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index 93121cf..174d7eb 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
 
-Makefiles for  libpng version 1.5.1beta02 - January 14, 2011
+Makefiles for  libpng version 1.5.1beta03 - January 15, 2011
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
-                       (gcc, creates libpng15.so.15.1.5.1beta02)
+                       (gcc, creates libpng15.so.15.1.5.1beta03)
  makefile.gcc      =>  Generic makefile (gcc, creates static libpng.a)
  makefile.knr      =>  Archaic UNIX Makefile that converts files with
                        ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@
  makefile.dec      =>  DEC Alpha UNIX makefile
  makefile.dj2      =>  DJGPP 2 makefile
  makefile.elf      =>  Linux/ELF makefile symbol versioning,
-                       (gcc, creates libpng15.so.15.1.5.1beta02)
+                       (gcc, creates libpng15.so.15.1.5.1beta03)
  makefile.freebsd  =>  FreeBSD makefile
  makefile.gcc      =>  Generic gcc makefile
  makefile.hpgcc    =>  HPUX makefile using gcc
@@ -35,12 +35,12 @@
  makefile.os2      =>  OS/2 Makefile (gcc and emx, requires libpng.def)
  makefile.sco      =>  For SCO OSr5  ELF and Unixware 7 with Native cc
  makefile.sggcc    =>  Silicon Graphics (gcc,
-                       creates libpng15.so.15.1.5.1beta02)
+                       creates libpng15.so.15.1.5.1beta03)
  makefile.sgi      =>  Silicon Graphics IRIX makefile (cc, creates static lib)
  makefile.solaris  =>  Solaris 2.X makefile (gcc,
-                       creates libpng15.so.15.1.5.1beta02)
+                       creates libpng15.so.15.1.5.1beta03)
  makefile.so9      =>  Solaris 9 makefile (gcc,
-                       creates libpng15.so.15.1.5.1beta02)
+                       creates libpng15.so.15.1.5.1beta03)
  makefile.std      =>  Generic UNIX makefile (cc, creates static libpng.a)
  makefile.sunos    =>  Sun makefile
  makefile.32sunu   =>  Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 72e74fa..9f48346 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
 
 # Modeled after libxml-config.
 
-version=1.5.1beta02
+version=1.5.1beta03
 prefix=""
 libdir=""
 libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index d87f04c..51e728f 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@
 
 Name: libpng
 Description: Loads and saves PNG files
-Version: 1.5.1beta02
+Version: 1.5.1beta03
 Libs: -L${libdir} -lpng15
 Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index a3a7478..d9e0840 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@
 
 LIB=	png15
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.5.1beta02
+SHLIB_MINOR=	1.5.1beta03
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index b5ba20a..f8d15f4 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@
 
 LIB=	png
 SHLIB_MAJOR=	15
-SHLIB_MINOR=	1.5.1beta02
+SHLIB_MINOR=	1.5.1beta03
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index a9c5b49..baf3be1 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@
 MANDIR= ${PREFIX}/man/cat
 
 SHLIB_MAJOR=	15
-SHLIB_MINOR=	1.5.1beta02
+SHLIB_MINOR=	1.5.1beta03
 
 LIB=	png
 SRCS=	png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/symbols.def b/scripts/symbols.def
index d98f4ff..24523ce 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -5,7 +5,7 @@
 LIBRARY
 
 EXPORTS
-;Version 1.5.1beta02
+;Version 1.5.1beta03
  png_access_version_number @1
  png_set_sig_bytes @2
  png_sig_cmp @3
diff --git a/png.h b/png.h
index fa4f76c..dd47979 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.5.1beta02 - January 14, 2011
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.5.1beta02 - January 14, 2011: Glenn
  *   See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -144,7 +144,8 @@
  *    1.5.0beta01-58          15    10500  15.so.15.0[.0]
  *    1.5.0rc01-07            15    10500  15.so.15.0[.0]
  *    1.5.0                   15    10500  15.so.15.0[.0]
- *    1.5.1beta01-02          15    10501  15.so.15.1[.0]
+ *    1.5.1beta01-03          15    10501  15.so.15.1[.0]
+ *    1.5.1rc01               15    10501  15.so.15.1[.0]
  *
  *   Henceforth the source version will match the shared-library major
  *   and minor numbers; the shared-library major version number will be
@@ -176,7 +177,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.5.1beta02, January 14, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -288,13 +289,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    January 14, 2011
+ *    January 15, 2011
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.5.1beta02 are Y2K compliant.  It is my belief that
  *    earlier versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -350,9 +351,9 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.1beta02"
+#define PNG_LIBPNG_VER_STRING "1.5.1beta03"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.5.1beta02 - January 14, 2011\n"
+     " libpng version 1.5.1beta03 - January 15, 2011\n"
 
 #define PNG_LIBPNG_VER_SONUM   15
 #define PNG_LIBPNG_VER_DLLNUM  15
@@ -365,7 +366,7 @@
  * PNG_LIBPNG_VER_STRING, omitting any leading zero:
  */
 
-#define PNG_LIBPNG_VER_BUILD  02
+#define PNG_LIBPNG_VER_BUILD  03
 
 /* Release Status */
 #define PNG_LIBPNG_BUILD_ALPHA    1
@@ -507,7 +508,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef char* png_libpng_version_1_5_1beta02;
+typedef char* png_libpng_version_1_5_1beta03;
 
 /* Three color definitions.  The order of the red, green, and blue, (and the
  * exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.5.1beta02 - January 14, 2011
+ * libpng version 1.5.1beta03 - January 15, 2011
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.5.1beta02 - January 14, 2011: Glenn
+ *   libpng versions 0.97, January 1998, through 1.5.1beta03 - January 15, 2011: Glenn
  *   See also "Contributing Authors", below.
  *
@@ -176,7 +177,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.5.1beta02, January 14, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.1beta03, January 15, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
@@ -288,13 +289,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.5.1beta02 are Y2K compliant.  It is my belief that
+ *    upward through 1.5.1beta03 are Y2K compliant.  It is my belief that
  *    earlier versions were also Y2K compliant.
  *